@@ -1,3 +1,6 @@
+use std::env;
+use std::fs::File;
+use std::io::{Write};
 use nxui::util::*;
 use nxui::window::demowindow::DemoWindow;
 fn main() {
