@@ -30,7 +30,7 @@ impl Application for DemoWindow {
 
     fn startup(&self,storage: Storage) {
         println!("Startup!");
-        println!("Config dir is {}",storage.get_config_dir().as_os_str().to_str().unwrap());
+        storage.create_config_dir();
     }
 
     fn ui(&self,frame: Frame) {
