@@ -169,7 +169,7 @@ pub trait Application {
     }
 
     /// Processing at application startup (optional)
-    fn startup(&self,_storage: Storage) {
+    fn startup(&self,storage: Storage) {
     }
 
     /// Writing UI processes and events
@@ -311,13 +311,12 @@ pub trait Application {
     /// Returns WindowAttributes.
     fn attributes(&self) -> Attributes;
 
-    #[cfg(feature="nxui-awc")]
     fn advanced_options(&self) -> AdvancedOptions {
         AdvancedOptions::default()
     }
 
     /// Processing at application startup (optional)
-    fn startup(&self,storage: Storage) {
+    fn startup(&mut self,storage: Storage) {
 
     }
     /// Writing UI processes and events
